package com.citygis.service.impl;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.citygis.common.pojo.AjaxResult;
import com.citygis.domain.CdcTbCrbbgk;
import com.citygis.domain.TimeBase;
import com.citygis.domain.dto.Area;
import com.citygis.domain.dto.AreaData;
import com.citygis.domain.dto.HistogramDto;
import com.citygis.domain.dto.XYDto;
import com.citygis.mapper.CdcTbCrbbgkMapper;
import com.citygis.service.ICdcTbCrbbgkService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author shcd
 * @since 2024-09-19
 */
@Service
public class CdcTbCrbbgkServiceImpl extends ServiceImpl<CdcTbCrbbgkMapper, CdcTbCrbbgk> implements ICdcTbCrbbgkService {

    @Resource
    CdcTbCrbbgkMapper cdcTbCrbbgkMapper;

    @Override
    public AjaxResult getHistogramData() {
        List<HistogramDto> histogramData = cdcTbCrbbgkMapper.getHistogramData();

        List<String> list = histogramData.stream()
                .map(histogramDto -> histogramDto.getMonth())
                .distinct()
                .collect(Collectors.toList());

        Map<String, List<HistogramDto>> map = list.stream()
                .collect(Collectors.toMap(
                        month -> month,
                        month -> screeningMonth(month, histogramData)
                ));

        return AjaxResult.success(map);
    }

    public List<HistogramDto> screeningMonth(String month, List<HistogramDto> histogramDtos) {
        return histogramDtos.stream()
                .filter(histogramDto -> histogramDto.getMonth().equals(month))
                .collect(Collectors.toList());
    }

    @Override
    public AjaxResult getDataByArea() {
        List<Area> area = cdcTbCrbbgkMapper.getArea();
        List<AreaData> dataByArea = cdcTbCrbbgkMapper.getDataByArea();
        Map<String, List<AreaData>> map1 = area.stream()
                .collect(Collectors.toMap(
                        Area::getArea,
                        area1 -> screeningArea(area1, dataByArea)
                ));
        return AjaxResult.success(map1);
    }

    @Override
    public AjaxResult sprinkleSomeByType(TimeBase timeBase) {
        List<XYDto> xyDtos = new ArrayList<>();
        Integer type = timeBase.getType();
        switch (type) {
            case 1:
                xyDtos = cdcTbCrbbgkMapper.crbSD(timeBase);
                break;
            case 2:
                xyDtos = cdcTbCrbbgkMapper.frSD(timeBase);
                break;
            case 3:
                xyDtos = cdcTbCrbbgkMapper.fzSD(timeBase);
                break;
            case 4:
                xyDtos = cdcTbCrbbgkMapper.gmSD(timeBase);
                break;
        }
        return AjaxResult.success(xyDtos);
    }

    public List<AreaData> screeningArea(Area area, List<AreaData> dataByArea) {
        return dataByArea.stream()
                .filter(areaData -> areaData.getJzdXia().equals(area.getArea()))
                .collect(Collectors.toList());
    }
}
